summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorVitiko <[email protected]>2023-06-14 04:08:36 -0400
committerVitiko <[email protected]>2023-06-14 04:08:36 -0400
commit304ad160e0157ed98d3bc30d5512b23e9ce233e9 (patch)
tree63cbe48ac5c455b1b38833af38b13e0945a1ec70
parent2b0e435f6a6485e833233f9fab9203ef1b02d184 (diff)
downloadbazarr-304ad160e0157ed98d3bc30d5512b23e9ce233e9.tar.gz
bazarr-304ad160e0157ed98d3bc30d5512b23e9ce233e9.zip
Subf2m provider: improve queriesv1.2.2-beta.19
-rw-r--r--libs/subliminal_patch/providers/subf2m.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/libs/subliminal_patch/providers/subf2m.py b/libs/subliminal_patch/providers/subf2m.py
index 2f400287d..ac0daafc2 100644
--- a/libs/subliminal_patch/providers/subf2m.py
+++ b/libs/subliminal_patch/providers/subf2m.py
@@ -185,9 +185,9 @@ class Subf2mProvider(Provider):
logger.debug("Access to this resource is forbidden: %s", url)
break
# Sometimes subf2m will return a 503 code. This error usually disappears
# retrying the query
- if req.status_code == 503:
+ if req.status_code in (404, 503):
logger.debug("503 returned. Trying again [%d] in 3 seconds", n + 1)
time.sleep(3)
continue
@@ -185,9 +185,9 @@ class Subf2mProvider(Provider):
logger.debug("Access to this resource is forbidden: %s", url)
break
- # Sometimes subf2m will return a 503 code. This error usually disappears
+ # Sometimes subf2m will return 404 or 503. This error usually disappears
# retrying the query